#ifndef _Q_CHANNELRUNDATA_HH_
#define _Q_CHANNELRUNDATA_HH_

/**
 * @file QChannelRunData.hh
 * @class QChannelRunData
 * @ingroup objects_detector
 * @brief basic channel and run based info. Used in the QRunData object.
 * @author Marco Vignati
 */

#include "QObject.hh"
#include <string>

class QChannelRunData : public Diana::QObject {

    public:
       /** @brief clear members */
       void Clear() 
       {
            fADC2mV = Q_DOUBLE_DEFAULT;
            fSamplingFrequency = Q_DOUBLE_DEFAULT;
            fADCMax = Q_INT_DEFAULT;
            fADCMin = Q_INT_DEFAULT;
            fNumberOfSamples = Q_INT_DEFAULT;
            fIsBolometer = false;
            fIsThermometer = false;
       }

       /** @brief conversion: mV = ADC * fADC2mV */
       double fADC2mV;
       /** @brief sampling frequency in Hz */
       double fSamplingFrequency;
       /** @brief ADC maximum in ADC units */
       int fADCMax;
       /** @brief ADC minimum in ADC units */
       int fADCMin;
       /** @brief number of samples in ADC window */
       int fNumberOfSamples;
       /** @brief is bolometer */
       bool fIsBolometer;
       /** @brief is thermometer */
       bool fIsThermometer;
    private:

        QObjectDef(QChannelRunData,5);

};

#endif
