#include "QChannelRunDataHandle.hh"
#include "QDianaDb.hh"
#include "QStringHandler.hh"
#include <cmath>

using namespace Diana;

QChannelRunDataHandle::QChannelRunDataHandle(const int run, const int channel, const std::string& name) : GlobalHandle<QChannelRunData>(name,"DAQ")
{
    SetChannel(channel);
    SetRun(run);
}

QError QChannelRunDataHandle::FillFromDB()
{
    QError err = QERR_SUCCESS;
    QChannelRunData chanData;
    chanData.Clear();

    std::string sbSubQuery = "(SELECT settings_basket_id FROM runs"
       " WHERE run_number = " + QStringHandler::IntToString(GetRun()) + ")";
    std::string profileIdSubQuery = "(SELECT profile_id FROM settings_basket"
       " WHERE settings_basket_id = " + sbSubQuery + ")"; 

    std::string query = "SELECT"
       " daq_nbits, sampling_frequency, v_adc_limit_min, v_adc_limit_max, window_length_ms"
       " FROM digitizers, daqsettings, buildersettings"
       " WHERE"
       " channel = " + QStringHandler::IntToString(GetChannel())
       + " AND daq_set = (SELECT daq_set from settings_basket WHERE settings_basket_id = " + sbSubQuery + ")"
       " AND bld_set = (SELECT bld_set from settings_basket WHERE settings_basket_id = " + sbSubQuery + ")"
       " AND digitizers.daq_id = (SELECT daq_id FROM maps WHERE channel = " + QStringHandler::IntToString(GetChannel())
       + "     AND profile_id = " + profileIdSubQuery + ")"
       " AND digitizers.daq_id = daqsettings.daq_id;";
    
    // std::cout << " = = = = = = = = = = = = = = "
    // 	      << std::endl << query << std::endl
    // 	      << " = = = = = = = = = = = = = = " << std::endl;

    QDb::QDbTable chanDataInfo;
    err = QDianaDb::Get()->DoQuery(query, chanDataInfo);
    if(err != QERR_SUCCESS)
       return err;
    

    chanData.fSamplingFrequency = chanDataInfo["sampling_frequency"].begin()->GetInt();
    int ADCRange = (1<<(chanDataInfo["daq_nbits"].begin()->GetInt()));
    double adcMaxV = chanDataInfo["v_adc_limit_max"].begin()->GetDouble();
    double adcMinV = chanDataInfo["v_adc_limit_min"].begin()->GetDouble();
    chanData.fADC2mV = (adcMaxV - adcMinV) / ADCRange;
    chanData.fADCMax = (int) (adcMaxV / chanData.fADC2mV)-1;
    chanData.fADCMin = (int) (adcMinV / chanData.fADC2mV);
    chanData.fADC2mV*=1000;
    chanData.fNumberOfSamples
       = (chanDataInfo["window_length_ms"].begin()->GetInt()*chanData.fSamplingFrequency)/1000; //


    query = "SELECT td_kind FROM thermaldetectors WHERE td_id ="
       " (SELECT td_id FROM maps WHERE channel = " + QStringHandler::IntToString(GetChannel())
       + " AND profile_id = " + profileIdSubQuery + ")" 
       " UNION SELECT NULL;";

    // std::cout << " =+=+=+=+=+=+=+=+=+=+=+=+=+= "
    // 	      << std::endl << query << std::endl
    // 	      << " =+=+=+=+=+=+=+=+=+=+=+=+=+= " << std::endl;

    QDb::QDbTable tdInfo;
    err = QDianaDb::Get()->DoQuery(query, chanDataInfo);
    if(err != QERR_SUCCESS)
       return err;

    chanData.fIsBolometer = false;
    chanData.fIsThermometer = false;
    std::string tdKind = chanDataInfo["td_kind"].begin()->GetString();
    if(!tdKind.empty())
    {
       if("bolometer" == tdKind)
    	  chanData.fIsBolometer= true;
       else if("thermometer" == tdKind)
	      chanData.fIsThermometer = true;
    } // else it is another DAQ channel used in specific cases like pulser channel or bias channel

    Set(chanData);
    return QERR_SUCCESS;
}
