/**
 * @file QDbDefs.hh
 * @brief common definitions and enums for db classes
 */
#ifndef _Q_DB_DEFS_HH_
#define _Q_DB_DEFS_HH_
#include "QDiana.hh"
#include "QError.hh"
// MV/SDD FIXME: includes below to not change #include "QDbDefs.hh" everywhere
#include "QRunType.hh"
#include "QDetectorName.hh"

/**
 * @enum QApolloUserLevel
 * @brief user authentication levels allowed in the users db table
 *
 * Lower level corresponds to higher the privileges
 */
enum QApolloUserLevel {
    SoftwareLevel = -1,  /**< service users for internal software use */
    SuperUserLevel = 0,  /**< superuser */
    AddUserLevel = 5,    /**< can add new users */
    StartStopLevel = 10, /**< can start/stop measurements */
    ReadLevel = 20,      /**< read-only access level */
    NoPrivLevel = 99,    /**< can do nothing */
    InvalidLevel = 100,  /**< associated user is invalid -- can do nothing */
};

namespace QDbDefinitions
{
   /**
    * @enum QSettingsBasketKind
    * @brief used to retrieve and store settings baskets: the settings_basket_id 
    * depends also on the settings basket kind
    */
   enum QSettingsBasketKind{
      Unknown = 0,       /**< used to select any kind of SB */
      Online = 1,        /**< usual SB for data taking */
      Reprocess = 2,     /**< SB for retriggering */
   };

   /**
    * @brief this function defines the minimum allowed settings_basket_id for a 
    * given kind of settings basket (Online or Reprocess). -1 is returned when 
    * no limit is defined
    */
   int GetMinimumId(QSettingsBasketKind sbKind);
   
   /**
    * @brief this function defines the maximum allowed settings_basket_id for a 
    * given kind of settings basket (Online or Reprocess). -1 is returned when 
    * no limit is defined
    */
   int GetMaximumId(QSettingsBasketKind sbKind);

}
#endif
