#include "QDetectorName.hh"
#include <sstream>

DetectorName::DetectorName() : fDetectorName(DN_UNKNOWN)
{
    
}

DetectorName::DetectorName(const DetectorName& detectorName) : fDetectorName(detectorName.fDetectorName)
{
    
}

DetectorName::DetectorName(const DetectorName_& detectorName) : fDetectorName(detectorName)
{
    
}

const DetectorName& DetectorName::operator=(const DetectorName& rhs)
{
    fDetectorName = rhs.fDetectorName;
    return *this;
}

const DetectorName& DetectorName::operator=(const DetectorName_& rhs)
{
    fDetectorName = rhs;
    return *this;
}


std::string DetectorName::AsString() const
{
    std::string s;
    switch(fDetectorName) {
        case  DN_CUORICINO:   { s = "Cuoricino"; break; }
        case  DN_THREETOWERS: { s = "Three_Towers"; break; }
        case  DN_CUORE0:      { s = "Cuore0"; break; }
        case  DN_CUORE:       { s = "Cuore"; break; }
        case  DN_HALLA:       { s = "HallA"; break; }
        case  DN_HALLC:       { s = "HallC"; break; }
        case  DN_NUCLEUS:     { s = "NUCLEUS"; break; }
        case  DN_RANDD:       { s = "R&D"; break; } // Change it to the name of your R&D
        case  DN_BULLKID:     { s = "BULLKID"; break; }
        case  DN_UNKNOWN: 
        default:              { s = "UNKNOWN"; break; }
    }
    return s;
} 


QError DetectorName::Set(const int run)
{
    QError err = QERR_SUCCESS;
    int digit = (run/100000);    
    if(digit >= 0 && digit < 9) {
        fDetectorName = (DetectorName_)digit;
        return err;
    }

    fDetectorName = DN_UNKNOWN;
    err = QERR_UNKNOWN_ERR;
    std::stringstream msg;
    msg<<"Cannot convert run: \""<<run<<"\" into run detector name";
    err.SetDescription(__FILE__,__LINE__,msg.str());
    return err;

}

