#ifndef _Q_DETECTOR_NAME_HH_
#define _Q_DETECTOR_NAME_HH_

#include <string>
#include <QError.hh>

/**
 * @file QDetectorName.hh
 * @enum DetectorName_
 * @brief possible detector names
 * @author MV SDD
 */

enum DetectorName_ {
    DN_CUORICINO = 0,   /**< Cuoricino */
    DN_THREETOWERS = 1, /**< Three Towers */
    DN_CUORE0 = 2,      /**< Diana 0 */
    DN_CUORE = 3,       /**< Diana */
    DN_HALLA = 4,       /**< HallA crio (generic) */
    DN_HALLC = 5,       /**< HallC crio (generic) */
    DN_NUCLEUS = 6,     /**< NUCLEUS */
    DN_RANDD = 7,       /**< R&D (generic) */
    DN_BULLKID = 8,       /**< R&D (generic) */
    DN_UNKNOWN = 9,     /**< UNKNOWN */
};

/**
 * @file QDetectorName.hh
 * @class DetectorName
 * @brief class wrapper to DetectorName_
 * @author Marco Vignati
 */
class DetectorName {
    public:
        /** @brief ctor */
        DetectorName();
        /** @brief copy ctor */
        DetectorName(const DetectorName& detectorName);
        /** @brief copy ctor */
        DetectorName(const DetectorName_& detectorName);
        /** @brief operator =  */
        const DetectorName& operator=(const DetectorName& rhs);
        /** @brief operator =  */
        const DetectorName& operator=(const DetectorName_& rhs);
        /** @brief conversion operator  */
        operator DetectorName_() const { return fDetectorName; }
        /** @brief convert to string */
        std::string AsString() const;
        /** @brief convert from run number */
        QError Set(const int run);

        
    private:
        DetectorName_ fDetectorName;

        // QRootCintTrigger(DetectorName+)
    
};


#endif
