#include "QObject.hh"
#include <iostream>
#include <sstream>
#include "QObjectInspector.hh"
#include <TClass.h>

using namespace Diana;

ClassImp(QObject);


Q_BEGIN_NAMESPACE

QObject* QObject::New(const char* object) 
{
    TClass* cl = TClass::GetClass(object);
    if(!cl) return 0;
    if(cl->InheritsFrom("Diana::QObject")) 
        return (QObject*)cl->New();
    return 0;
}

QObject::QObject()
{
    InValidate();
    fTemporaryBits = 0;
    SetWrite(true);
    SetIsRequired(true);
    SetIsJustAdded(false);
}

QObject& QObject::operator=(const QObject& rhs)
{
    // prevent from copying QObject members.
    this->TObject::operator=(rhs); 
    return *this;
}

void QObject::FullyFill(QObject* evData) const
{
    bool valid = false;
    if(IsValid()) {
        valid = this->Fill(evData);
    }
    if(valid) {
        evData->Validate();
    } else {
        evData->InValidate();
    }
    this->CopyBits(evData);
}

void QObject::Dump(std::ostream& ob) const
{
    // by default use WriteOnStream
    QObjectInspector insp;
    ob<<"Dump not implemented, using auto-dump method:"<<std::endl;
    QError err = insp.DumpOnStream(this,ob);
    if(err != QERR_SUCCESS) ob << "auto-dump failed with error: "<<err.GetDescription()<<std::endl;
}

QError QObject::WriteOnStream(std::ostream& ob) const
{
    QObjectInspector insp;
    return insp.DumpOnStream(this,ob);
}

QError QObject::ReadFromStream(std::istream& ob) 
{

    QObjectInspector insp;
    return insp.FillFromStream(this,ob);
}

void QObject::QObjectSetBit(int bit, bool value)
{
    if(value) {
        fTemporaryBits |= bit;
    } else {
        fTemporaryBits &= ~bit;
    }
}

void QObject::CopyBits(QObject* obj) const
{
    if(this->IsValid()) {
        obj->Validate();
    }
    obj->fTemporaryBits = fTemporaryBits;
}

bool QObject::QObjectTestBit(int bit) const
{
    return fTemporaryBits & bit;
}


Q_END_NAMESPACE

std::ostream& operator<<(std::ostream&s,const Diana::QObject&t)
{
    t.Dump(s);
    return s;
}
