#ifndef _QRUNDATA_HH_
#define _QRUNDATA_HH_

/**
* @file QRunData.hh
* @class QRunData
* @ingroup objects_detector
* @brief Basic run based info
* @author Marco Vignati
*/

#include "QObject.hh"
#include "QRunType.hh"
#include "QDetectorName.hh"
#include "QChannelRunData.hh"
#include <map>
#include <ctime>
#include "Rtypes.h"

class QRunData : public Diana::QObject {

    public:
        
        ~QRunData(){
            Clear();
        }   
        
        /** @brief Clear members */
        virtual void Clear();

        /** @brief Write object on stream */
        virtual QError WriteOnStream (std::ostream &o) const;      
   
        /** @brief Read object from stream */
        virtual QError ReadFromStream (std::istream &ob);      

        /** @brief dump object to stream */
        virtual void Dump(std::ostream& o) const ;

        /** @brief Run Number */
        int fNumber;
        /** @brief Source Run Number */
        DetectorName fDetector;
        /** @brief Run Type */
        RunType fType;
        /** @brief Thermal detector channels: union of fBolometerChannels and  fThermometerChannels */
        std::vector<int> fThermalDetectorChannels;
        /** @brief Bolometers channels (thermistors glued to a crystal) */
        std::vector<int> fBolometerChannels;
        /** @brief Thermometers channels (thermistors not glued to a crystal) */
        std::vector<int> fThermometerChannels;
        /** @brief get channel based run data quantities */
        const QChannelRunData& GetChannelRunData(const int channel) const;
        /** @brief get channel based run data quantities */
        const std::map<int,QChannelRunData*>& GetChannelsRunData() const { return fChannelsRunData;}
        
        QRunData& operator=(const QRunData& other);

        /** @brief set channel based run data quantities */
        void SetChannelRunData(const int channel, const QChannelRunData& chanRunData);
        /** @brief StartTime */
        time_t fStartDate;
        /** @brief StopTime */
        time_t fStopDate;
        /** @brief Duration */
        time_t fDuration;
        
    private:
        /** @brief channel based quantities */
        std::map<int,QChannelRunData*> fChannelsRunData;

public:
   int fSourceRun;
   /** @brief Detector name */
   /** @brief Source Run Type */
   RunType fSourceType;

   QObjectDef(QRunData,6);
};


#endif
