#include "QRunDataHandle.hh"
#include "QChannelRunDataHandle.hh"
#include "QDianaDb.hh"
#include <sstream>

using namespace Diana;

QRunDataHandle::QRunDataHandle(const int run, const std::string& name): GlobalHandle<QRunData>(name,"DAQ")
{
    SetRun(run);
    fIsOnline = false;
}

void QRunDataHandle::FillBasicInfo(QRunData& runData)
{
    runData.fDetector.Set(GetBeginRun());
    runData.fNumber = GetBeginRun();
}

QError QRunDataHandle::FillFromFile(const std::string& fname)
{
    QError err = QERR_SUCCESS;
    QRunData runData;
    runData.Clear();
    FillBasicInfo(runData);
    if(fname == "NONE") {
        Set(runData);
        return err;
    }
    err = this->GlobalHandle<QRunData>::FillFromFile(fname);
    return err;
}

QError QRunDataHandle::FillFromDB()
{
    QError myerr = QERR_SUCCESS, err = QERR_SUCCESS; 

    QRunData runData;
    runData.Clear();
    FillBasicInfo(runData);

    int run = runData.fNumber;

    QDianaDb *db = QDianaDb::Get();
    // Run type
    try  {
        std::stringstream squery;
        squery<<"SELECT run_type from runs where run_number =  "<<run; 

        std::string srun =	db->DoQueryString(squery.str());
        QError err = runData.fType.Set(srun);
        if(err != QERR_SUCCESS) throw err;

    }
    catch(QError& err) {
        char berr[1024];
        sprintf(berr,"Could not find RunType for run %06d in DB: %s",run,err.GetDescription().c_str());
        myerr = QERR_GLOBAL_HANDLE;
        myerr.SetDescription(__FILE__,__LINE__,berr);
        return myerr;
    }

    /*
     * Use run (as opposed to source run) to retrieve all the information.
     * This way we get the proper trigger and event building configuration
     * while the other hardware parameters will likely be the same between
     * the sb of the run and the sb of the source run.
     */
    
    // start date
    try {
      std::stringstream squery;
      squery<<"SELECT  date_part('epoch', start_date) FROM runs WHERE "
	    <<"run_number = "<< GetRun();
      runData.fStartDate = (time_t) db->DoQueryDouble(squery.str());
    }
    catch(QError& err) {
        char berr[1024];
        sprintf(berr,"Could not find StartDate for run %06d in DB: %s",run,err.GetDescription().c_str());
        myerr = QERR_GLOBAL_HANDLE;
        myerr.SetDescription(__FILE__,__LINE__,berr);
        return myerr;
    }

    // end date (compute also duration)
    try {
      std::stringstream squery;
      squery<<"SELECT  date_part('epoch', stop_date) FROM runs WHERE "
	    <<"run_number = "<< GetRun();
      runData.fStopDate = (time_t) db->DoQueryDouble(squery.str());
        runData.fDuration= runData.fStopDate-runData.fStartDate;


    }
    catch(QError& err) {
        char berr[1024];
        sprintf(berr,"Could not find StopDate for run %06d in DB: %s",run,err.GetDescription().c_str());
        if(!fIsOnline) {
            myerr = QERR_GLOBAL_HANDLE;
            myerr.SetDescription(__FILE__,__LINE__,berr);
            return err;
        } else {
            QMessageHandler::Info("QRunDataHandle::FillFromDB",berr);
        }
    }

    // everything ok if we arrived here 
    Set(runData);
    return myerr;
}

QError QRunDataHandle::StoreOnDB() const
{
    QError err = QERR_NOT_IMPLEMENTED; // (yet)
    err.SetDescription("StoreOnDB() not implemented for QRunDataHandle");
    /*
       const QVector& ap = Get();
       int beginRun,endRun;
       GetValidityInterval(beginRun,endRun);
    // set ap and validity in db 
    */
    return err;
}


