#include "QRunType.hh"
#include <sstream>


RunType::RunType() : fRunType(RT_UNKNOWN)
{
    
}

RunType::RunType(const RunType& runType) : fRunType(runType.fRunType)
{
    
}

RunType::RunType(const RunType_& runType) : fRunType(runType)
{
    
}

const RunType& RunType::operator=(const RunType& rhs)
{
    fRunType = rhs.fRunType;
    return *this;
}

bool RunType::operator==(const RunType& rhs) const
{
    return fRunType == rhs.fRunType;
}

bool RunType::operator==(const RunType_& rhs) const
{
    return fRunType == rhs;
}



const RunType& RunType::operator=(const RunType_& rhs)
{
    fRunType = rhs;
    return *this;
}


std::string RunType::AsString(RunType_ runType)
{
    std::string s;
    switch(runType) {
        case RT_CALIBRATION: { s = "Calibration"; break; }
        case RT_BACKGROUND:  { s = "Background"; break; }
        case RT_NPULSES:     { s = "NPulses"; break; }
        case RT_TEST:        { s = "Test"; break; }
        case RT_MONTECARLO:  { s = "MonteCarlo"; break; }
        case RT_PHYSICS:  { s = "Physics"; break; }
        case RT_REPROCESS: { s = "Reprocess"; break; }
        case RT_S_LOADCURVES: { s = "Setup_LoadCurves"; break; }
        case RT_S_WORKINGPOINT: { s = "Setup_WorkingPoint"; break; }
        case RT_S_HEATERSET: { s = "Setup_HeaterSet"; break; }
        case RT_S_GAINSET: { s = "Setup_GainSet"; break; }
        case RT_S_OFFSETSET: { s = "Setup_OffsetSet"; break; }
        case RT_S_ELECHECK: { s = "Setup_EleCheck"; break; }
        case RT_S_LOADCURVES_OF: { s = "Setup_LoadCurves_OF"; break; }
        case RT_CALIBRATION_TH232: { s = "Calibration_Th232"; break; }
        case RT_CALIBRATION_CO60: { s = "Calibration_Co60"; break; }
        case RT_CALIBRATION_CO56: { s = "Calibration_Co56"; break; }
        case RT_BACKGROUND_PARKEDSTRINGS: { s = "Background_ParkedStrings"; break; }
        case RT_UNKNOWN:
        default:             { s = "UNKNOWN"; break; } 
    }
    return s;
}

std::string RunType::AsAbbreviation(RunType_ runType) {

    std::string s;
    switch(runType) {
        case RT_CALIBRATION:       { s = "Calib"; break; }
        case RT_BACKGROUND:        { s = "Bkgnd"; break; }
        case RT_NPULSES:           { s = "NPuls"; break; }
        case RT_TEST:              { s = "ATest"; break; }
        case RT_MONTECARLO:        { s = "MCarl"; break; }
        case RT_PHYSICS:           { s = "Physc"; break; }
        case RT_REPROCESS:         { s = "Repro"; break; }
        case RT_S_LOADCURVES:      { s = "LoadC"; break; }
        case RT_S_WORKINGPOINT:    { s = "WorkP"; break; }
        case RT_S_HEATERSET:       { s = "Heatr"; break; }
        case RT_S_GAINSET:         { s = "GainS"; break; }
        case RT_S_OFFSETSET:       { s = "Offst"; break; }
        case RT_S_ELECHECK:        { s = "EleCk"; break; }
        case RT_S_LOADCURVES_OF:   { s = "LdCOF"; break; }
        case RT_CALIBRATION_TH232:       { s = "CTh232"; break; }
        case RT_CALIBRATION_CO60:        { s = "CCo-60"; break; }
        case RT_CALIBRATION_CO56:        { s = "CCo-56"; break; }
        case RT_BACKGROUND_PARKEDSTRINGS:{ s = "BkgSt"; break; }
        case RT_UNKNOWN:
        default:             { s = "UKNWN"; break; } 
    }
    return s;
}

QError RunType::Set(const std::string& s) 
{
   fRunType = RT_UNKNOWN;
    QError err = QERR_SUCCESS;
    if(s == "Calibration" || s == "C" || s == "Calib") fRunType = RT_CALIBRATION;
    else if(s == "Background" || s == "B" || s == "Bkgnd") fRunType = RT_BACKGROUND;
    else if(s == "NPulses" || s == "N" || s == "NPuls") fRunType = RT_NPULSES;
    else if(s == "Test" || s == "T" || s == "ATest") fRunType = RT_TEST;
    else if(s == "MonteCarlo"|| s == "M" || s == "MCarl") fRunType = RT_MONTECARLO;
    else if(s == "Physics"|| s == "P" || s == "Physc") fRunType = RT_PHYSICS;
    else if(s == "Reprocess"|| s == "R" || s == "Repro") fRunType = RT_REPROCESS;
    else if(s == "Setup_LoadCurves"|| s == "SL" || s == "LoadC") fRunType = RT_S_LOADCURVES;
    else if(s == "Setup_WorkingPoint"|| s == "SW" || s == "WorkP") fRunType = RT_S_WORKINGPOINT;
    else if(s == "Setup_HeaterSet"|| s == "SH" || s == "Heatr") fRunType = RT_S_HEATERSET;
    else if(s == "Setup_GainSet"|| s == "SG" || s == "GainS") fRunType = RT_S_GAINSET;
    else if(s == "Setup_OffsetSet"|| s == "SO" || s == "Offst") fRunType = RT_S_OFFSETSET;
    else if(s == "Setup_EleCheck"|| s == "SE" || s == "EleCk") fRunType = RT_S_ELECHECK;
    else if(s == "Setup_LoadCurves_OF"|| s == "SLO" || s == "LdCOF") fRunType = RT_S_LOADCURVES_OF;
    else if(s == "Calibration_Th232" || s == "CTh232") fRunType = RT_CALIBRATION_TH232;
    else if(s == "Calibration_C060" || s == "CCo-60") fRunType = RT_CALIBRATION_CO60;
    else if(s == "Calibration_C056" || s == "CCo-56") fRunType = RT_CALIBRATION_CO56;

    else if(s == "Background_ParkedStrings" || s == "BkgSt") fRunType = RT_BACKGROUND_PARKEDSTRINGS; 

    else {
        fRunType = RT_UNKNOWN;
        err = QERR_UNKNOWN_ERR;
        std::stringstream msg;
        msg<<"Cannot convert: \""<<s<<"\" into run type";
        err.SetDescription(__FILE__,__LINE__,msg.str());
    }
    return err;
}


