#ifndef _Q_RUNTYPE_HH_
#define _Q_RUNTYPE_HH_

#include <string>
#include <QError.hh>
/**
 * @file QRunType.hh
 * @enum RunType_
 * @brief allowed run types
 * @author MV SDD
 */

enum RunType_ {
   RT_UNKNOWN = 0,     /**< runtype is unknown */
   RT_BACKGROUND = 1,  /**< background measurement */
   RT_CALIBRATION = 2, /**< calibration measurement */
   RT_NPULSES = 3,     /**< heater pulses at several amplitudes */
   RT_TEST = 4,        /**< test measurement */
   RT_REPROCESS = 5,   /**< reprocess data starting from gz files */
   RT_MONTECARLO = 6,   /**< simulated data */
   RT_PHYSICS = 7,   /**< background + calibration */
   RT_S_LOADCURVES = 10, /**< detector setup: load curves */   
   RT_S_WORKINGPOINT = 11, /**< detector setup: working point */   
   RT_S_HEATERSET = 12,  /**< detector setup: heater set */   
   RT_S_GAINSET = 13, /**< detector setup: gain set */   
   RT_S_OFFSETSET = 14, /**< detector setup: offset */   
   RT_S_ELECHECK = 15,  /**< detector setup: electronics check */   
   RT_S_LOADCURVES_OF = 16, /**< detector setup: load curves with OF */

   RT_CALIBRATION_TH232 = 17,
   RT_CALIBRATION_CO60 = 18,
   RT_CALIBRATION_CO56 = 19,

   RT_BACKGROUND_PARKEDSTRINGS = 20,
   

};

/**
 * @file QRunType.hh
 * @class RunType
 * @brief class wrapper to RunType_
 * @author MV
 */
class RunType {
    public:
        /** @brief ctor */
        RunType();
        /** @brief copy ctor */
        RunType(const RunType& runType);
        /** @brief copy ctor */
        RunType(const RunType_& erunType);
        /** @brief operator ==  */
        bool operator==(const RunType& rhs) const;
        /** @brief operator ==  */
        bool operator==(const RunType_& rhs) const;
        /** @brief operator =  */
        const RunType& operator=(const RunType& rhs);
        /** @brief operator =  */
        const RunType& operator=(const RunType_& rhs);
        /** @brief conversion operator  */
        operator RunType_() const { return fRunType; }
        /** @brief convert to string */
        std::string AsString() const { return AsString(fRunType); }
        /** \brief convert to string */
        static std::string AsString(RunType_ Type);
        /** @brief convert to abbreviation */
        std::string AsAbbreviation() const { return AsAbbreviation(fRunType); }
        /** @brief convert to abbreviation */
        static std::string AsAbbreviation(RunType_ Type);
        /** @brief convert from string */
        QError Set(const std::string&);

        
    private:
        RunType_ fRunType;

        // QRootCintTrigger(RunType+)
    
};

#endif
